import React, { Component } from 'react';

import Indexes from './components/watch/Indexes';
import Hand from './components/watch/Hand';
import Grid from './components/watch/Grid';

import Background from 'react-backgrounds';

class Design extends Component {
  constructor(props) {
    super(props);

    this.state = {
      watchWidth: null,
      watchHeight: null
    }
  }

  componentDidMount() {
    this.setWatchDimensions();
    window.addEventListener("resize", this.setWatchDimensions.bind(this));
  }

  setWatchDimensions() {
    var width = this.watch.clientWidth,
      height = width;

    return this.setState({
      watchWidth: width,
      watchHeight: height
    });
  }

  getCaseClasses(styles) {
    var caseClasses = ['d-block'];

    var bg = styles.bg;
    caseClasses.push(bg);

    var padding = styles.padding;
    if (typeof padding === 'undefined') {
      padding = 'p-1';
    }
    caseClasses.push(padding);

    var shape = styles.shape;
    caseClasses.push(shape);

    return caseClasses.join(' ');
  }

  getDialClasses(styles) {
    var dialClasses = ['d-block'];

    if (styles.bg) {
      var bg = styles.bg.color;
      dialClasses.push(bg);
    }

    var padding = styles.padding;
    if (typeof padding === 'undefined') {
      padding = 'p-1';
    }
    dialClasses.push(padding);

    var shape = styles.shape;
    dialClasses.push(shape);

    return dialClasses.join(' ');
  }

  getBg(styles) {
    var type;
    if (styles.type) {
      type = styles.type;
    }

    var shapeCount;
    if (styles.shapeCount) {
      shapeCount = styles.shapeCount;
    }

    var colors;
    if (styles.colors) {
      colors = styles.colors;
    }

    var opacity;
    if (styles.opacity) {
      opacity = styles.opacity;
    }

    var bg = <Background type={type} shapeCount={shapeCount} colors={colors} opacity={opacity} />

    return bg;
  }

  getIndexes(styles) {
    return <Indexes styles={styles} />;
  }

  getHands(styles, timeZone) {
    var hands = [];
    var handCount = Object.keys(styles).length;
    var i = 1;

    while (i <= handCount) {
      var handStyles;
      if (styles[i] && styles[i].styles) {
        handStyles = styles[i].styles;
      }
      
      var handType;
      if (styles[i] && styles[i].type) {
        handType = styles[i].type;
      }

      var hand = (
        <Hand
          key={i}
          styles={handStyles}
          type={handType}
          timeZone={timeZone} />
      );

      hands.push(hand);

      i++;
    }

    return hands;
  }

  getGrid(styles) {
    return <Grid styles={styles} />
  }

  render() {
    var styles = this.props.styles;

    var caseClasses;
    if (styles.case) {
      caseClasses = this.getCaseClasses(styles.case);
    }

    var dialClasses;
    if (styles.dial) {
      dialClasses = this.getDialClasses(styles.dial);
    }

    var bg;
    if (styles.dial && styles.dial.bg && styles.dial.bg.pattern) {
      bg = this.getBg(styles.dial.bg.pattern);
    }

    var indexes;
    if (styles.index) {
      indexes = this.getIndexes(styles.index);
    }

    var hands;
    if (styles.hands) {
      hands = this.getHands(styles.hands, styles.timeZone);
    }

    var grid;
    if (styles.grid) {
      grid = this.getGrid(styles.grid);
    }

    return (
      <div
        ref={(watch) => { this.watch = watch; }}
        className={caseClasses}
        style={{
          height: this.state.watchHeight,
          border: 'solid black 1px'
        }}>
        <div
          className={dialClasses}
          style={{
            width: '100%',
            height: '100%',
            position: 'relative',
            border: 'solid black 1px',
            overflow: 'hidden'
          }}>
          {bg}
          {indexes}
          {grid}
          {hands}
        </div>
      </div>
    );
  }
}

export default Design;
