import React, { Component } from 'react';

import Label from './Label';
import Indexes from './Indexes';
import Hand from './Hand';

import Background from 'react-backgrounds';

class Grid extends Component {
    getLabel(styles) {
        return <Label styles={styles} />;
    }

    getIndexes(styles) {
        return <Indexes styles={styles} />;
    }

    getHands(styles, timeZone) {
        var hands = [];
        var handCount = Object.keys(styles).length;
        var i = 1;

        while (i <= handCount) {
            var handStyles;
            if (styles[i] && styles[i].styles) {
                handStyles = styles[i].styles;
            }

            var handType;
            if (styles[i] && styles[i].type) {
                handType = styles[i].type;
            }

            var hand = (
                <Hand
                    key={i}
                    styles={handStyles}
                    type={handType}
                    timeZone={timeZone} />
            );

            hands.push(hand);

            i++;
        }

        return hands;
    }

    getBg(styles) {
        var type;
        if (styles.type) {
            type = styles.type;
        }

        var shapeCount;
        if (styles.shapeCount) {
            shapeCount = styles.shapeCount;
        }

        var colors;
        if (styles.colors) {
            colors = styles.colors;
        }

        var opacity;
        if (styles.opacity) {
            opacity = styles.opacity;
        }

        var bg = <Background type={type} shapeCount={shapeCount} colors={colors} opacity={opacity} />

        return bg;
    }

    getDialClasses(styles) {
        var dialClasses = ['d-block', 'mx-auto'];

        if (styles.bg) {
            var bg = styles.bg.color;
            dialClasses.push(bg);
        }

        var padding = styles.padding;
        if (typeof padding === 'undefined') {
            padding = 'p-1';
        }
        dialClasses.push(padding);

        var shape = styles.shape;
        dialClasses.push(shape);

        return dialClasses.join(' ');
    }

    getGridNodes(styles) {
        var gridNodes = [];
        var i = 1;
        var gridCount = 9;

        while (i <= gridCount) {
            var dialClasses;
            var dialBorder;
            if (styles[i] && styles[i].dial) {
                dialClasses = this.getDialClasses(styles[i].dial);
                dialBorder = styles[i].dial.border;
            } else {
                dialClasses = null;
                dialBorder = null;
            }

            var bg;
            if (styles[i] && styles[i].dial && styles[i].dial.bg && styles[i].dial.bg.pattern) {
                bg = this.getBg(styles[i].dial.bg.pattern);
            } else {
                bg = null;
            }

            var indexes;
            if (styles[i] && styles[i].index) {
                indexes = this.getIndexes(styles[i].index);
            } else {
                indexes = null;
            }

            var hands;
            if (styles[i] && styles[i].hands) {
                hands = this.getHands(styles[i].hands, styles[i].timeZone);
            } else {
                hands = null;
            }

            var label;
            if (styles[i] && styles[i].label) {
                label = this.getLabel(styles[i].label);
            } else {
                label = null;
            }

            var gridNode = (
                <div
                    key={i}
                    className="col-4"
                    style={{
                        height: 'calc(100%/3)'
                    }} >
                    <div
                        className={dialClasses}
                        style={{
                            width: '100%',
                            height: '100%',
                            position: 'relative',
                            overflow: 'hidden',
                            border: dialBorder
                        }} >
                        {bg}
                        {hands}
                        {indexes}
                        {label}
                    </div>
                </div>
            );

            gridNodes.push(gridNode);

            i++;
        }

        return gridNodes;
    }

    render() {
        var gridNodes = this.getGridNodes(this.props.styles);

        return (
            <div
                className="row no-gutters"
                style={{
                    width: '100%',
                    height: '100%'
                }}>
                {gridNodes}
            </div>
        );
    }
};

export default Grid