import React, { Component } from 'react';

class Hand extends Component {
    constructor(props) {
        super(props);

        this.state = {
            timezoneOffset: null,
            hour: null,
            minute: null,
            second: null
        }
    }

    componentWillMount() {
        var dt = new Date();
        var timezoneOffset = dt.getTimezoneOffset() / 60;

        var hour;
        if (this.props.type === 'hour') {
            hour = dt.getHours();
        }

        var minute;
        if (this.props.type === 'minute') {
            minute = dt.getMinutes();
        }

        var second;
        if (this.props.type === 'second') {
            second = dt.getSeconds();
        }

        this.setState({
            timezoneOffset: timezoneOffset,
            hour: hour,
            minute: minute,
            second: second
        });
    }

    componentDidMount() {
        setInterval(this.updateTime.bind(this), 1000);
    }

    updateTime() {
        var dt = new Date(),
            hour = dt.getHours(),
            minute = dt.getMinutes(),
            second = dt.getSeconds();

        this.setState(
            {
                hour: hour,
                minute: minute,
                second: second
            }
        );
    }

    getHour(positionOffset) {
        var handPosition;
        var hour;

        if (typeof this.props.timeZone !== 'undefined') {
            hour = this.state.hour + (this.state.timezoneOffset + this.props.timeZone);
        } else {
            hour = this.state.hour;
        }

        if (hour >= 12) {
            hour = hour - 12;
        }

        if (hour === 0) {
            hour = 12;
        }

        handPosition = (hour * (360 / 12)) + positionOffset;

        return handPosition;
    }

    getMinute(positionOffset) {
        var minute = this.state.minute;
        var handPosition = (minute * 6) + positionOffset;

        return handPosition;
    }

    getSecond(positionOffset) {
        var second = this.state.second;
        var handPosition = (second * 6) + positionOffset;

        return handPosition;
    }

    getStyles(styles) {
        var handStyles = {};

        if (styles.color) {
            handStyles.backgroundColor = styles.color;
        }

        if (styles.border) {
            handStyles.border = styles.border;
        }

        if (styles.height) {
            handStyles.height = styles.height;
        }

        if (styles.margin) {
            handStyles.margin = styles.margin;
        } else {
            handStyles.margin = '0';
        }

        if (styles.width) {
            handStyles.width = styles.width;
        } else {
            handStyles.width = '50%';
        }

        if (styles.height) {
            handStyles.height = styles.height;
        } else {
            handStyles.height = '2px';
        }

        return handStyles;
    }

    render() {
        var handStyles;
        if (this.props.styles) {
            handStyles = this.getStyles(this.props.styles);
        }

        var positionOffset = 90;
        var handPosition = positionOffset;

        if (this.props.type) {
            if (this.props.type === 'hour') {
                handPosition = this.getHour(positionOffset);
            }

            if (this.props.type === 'minute') {
                handPosition = this.getMinute(positionOffset);
            }

            if (this.props.type === 'second') {
                handPosition = this.getSecond(positionOffset);
            }
        }

        var handWrapperStyles = {
            transform: '',
            zIndex: '15',
            position: 'absolute',
            top: '50%',
            left: '0',
            width: '100%',
            backgroundColor: 'transparent'
        };

        handWrapperStyles.transform = 'rotate(' + handPosition + 'deg)';

        return (
            <div className="hand" style={handWrapperStyles}>
                <div style={handStyles} />
            </div>
        )
    }
};

export default Hand