import React, { Component } from 'react';
import ReactDOM from 'react-dom';

import registerServiceWorker from './registerServiceWorker';

import App from './App';

import Minimal from './configurations/evolution/Minimal';
import MinimalRounded from './configurations/evolution/MinimalRounded';
import MinimalRoundedDetailed from './configurations/evolution/MinimalRoundedDetailed';

import Burst from './configurations/components/Burst';
import Iris from './configurations/components/Iris';
import IndexComponent from './configurations/components/IndexComponent';
import Hand from './configurations/components/Hand';

import Steel from './configurations/backgrounds/Steel';
import GreyFume from './configurations/backgrounds/GreyFume';

import Chronograph from './configurations/models/Chronograph';
import ColorfulChronoSquare from './configurations/models/ColorfulChronoSquare';
import Fire from './configurations/models/Fire';
import Panda from './configurations/models/Panda';
import PandaSquare from './configurations/models/PandaSquare';
import SmallSeconds from './configurations/models/SmallSeconds';
import SmallSecondsSquare from './configurations/models/SmallSecondsSquare';
import ColorfulChrono from './configurations/models/ColorfulChrono';
import Butterflies from './configurations/models/Butterflies';

import './index.css';

class Demo extends Component {
    render() {
        return (
            <div>
                <div className="bg-success text-white">
                    <div className="container">
                        <div className="row pt-5 pb-4">
                            <div className="col-md-12 col-lg-9">
                                <h1>Digital-Watch-Design</h1>
                                <h6 className="text-gray">Digital Watch Design is using web technologies (ReactJS and Bootstrap) to design a product line of watch faces that are inspired by some of the world's most interesting places.</h6>
                                <p className="text-gray mb-0">Check out the code on <a className="text-white" href="https://github.com/Harry-Anderson/react-bootstrap-design" target="_blank" rel="noopener noreferrer">GitHub</a>          and on <a className="text-white" href="https://www.npmjs.com/package/react-bootstrap-design" target="_blank" rel="noopener noreferrer">NPM</a></p>
                            </div>
                        </div>
                    </div>
                </div>
                <div className="container pt-4 pb-5">
                    <div className="row mb-4">
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{ColorfulChrono.header}</h4>
                            <App key="ColorfulChrono" styles={ColorfulChrono} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{Fire.header}</h4>
                            <App key="Fire" styles={Fire} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{SmallSecondsSquare.header}</h4>
                            <App key="SmallSecondsSquare" styles={SmallSecondsSquare} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{PandaSquare.header}</h4>
                            <App key="PandaSquare" styles={PandaSquare} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{ColorfulChronoSquare.header}</h4>
                            <App key="ColorfulChronoSquare" styles={ColorfulChronoSquare} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{SmallSeconds.header}</h4>
                            <App key="SmallSeconds" styles={SmallSeconds} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{Panda.header}</h4>
                            <App key="Panda" styles={Panda} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <h4 className="text-center">{Butterflies.header}</h4>
                            <App key="Butterflies" styles={Butterflies} />
                        </div>
                    </div>

                    <div className="row mb-4">
                        <div className="col-md-12 col-lg-9">
                            <h2>How it works</h2>
                            <p>Essentially, I am using Javascript and CSS to 'draw' watch faces. This process has certain benefits over conventional sketching and illustration. You'll notice that many of the watch faces have unconventional designs --colorful shapes, etc. If you refresh or resize your browser, you'll notice that those shapes will refresh each time.</p>
                            <p>These 'sketches' are created by layering different components on top of each other. Below are a few examples of these components.</p>
                        </div>
                    </div>

                    <div className="row">
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <App key="Minimal" styles={Minimal} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <App key="MinimalRounded" styles={MinimalRounded} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <App key="MinimalRoundedDetailed" styles={MinimalRoundedDetailed} />
                        </div>
                        <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                            <App key="Chronograph" styles={Chronograph} />
                        </div>
                    </div>

                    <div className="row">
                        <div className="col-md-12 col-lg-9">
                            <div className="row">
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App key="IndexComponent" styles={IndexComponent} />
                                </div>
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App key="Hand" styles={Hand} />
                                </div>
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App key="Burst" styles={Burst} />
                                </div>
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App key="Iris" styles={Iris} />
                                </div>
                            </div>
                        </div>
                    </div>

                    <div className="row">
                        <div className="col-md-12 col-lg-9">
                            <div className="row">
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App key="Steel" styles={Steel} />
                                </div>
                                <div className="col-sm-6 col-md-4 col-lg-3 my-3">
                                    <App key="GreyFume" styles={GreyFume} />
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <footer className="footer">
                    <div className="container">
                        <p className="mb-0">Created by <a href="https://harry-anderson.github.io/" target="_blank" rel="noopener noreferrer">Harry Anderson</a></p>
                    </div>
                </footer>
            </div>
        );
    }
}

ReactDOM.render(
    <Demo />,
    document.getElementById('root')
);

registerServiceWorker();
